@@ -59,7 +59,7 @@ private:
 	/* createConfigFolder
 	 * Create local folder where to put the configuration file. Path differs from
 	 * OS to OS. */
-	 
+
 	int createConfigFolder();
 
 public:
@@ -123,6 +123,13 @@ public:
 	int  beatsX, beatsY;
 	int  aboutX, aboutY;
 
+#ifdef WITH_VST
+
+	int pluginChooserX, pluginChooserY, pluginChooserW, pluginChooserH;
+	int pluginSortMethod;
+
+#endif
+
 	int  read();
 	int  write();
 };
