@@ -32,14 +32,17 @@
 
 
 /* -- version --------------------------------------------------------------- */
-#define G_VERSION_STR   "0.11.2"
+#define G_VERSION_STR   "0.12.2"
 #define G_APP_NAME      "Giada"
 #define G_VERSION_MAJOR 0
-#define G_VERSION_MINOR 11
+#define G_VERSION_MINOR 12
 #define G_VERSION_PATCH 2
 
 #define CONF_FILENAME		"giada.conf"
 
+#ifndef BUILD_DATE
+# define BUILD_DATE __DATE__
+#endif
 
 
 /* -- GUI ------------------------------------------------------------------- */
@@ -48,8 +51,10 @@
 #else
 	#define GUI_SLEEP			1000000/24 // == 1.000.000 / 24 == 1/24 sec == 24 Hz
 #endif
-#define GUI_WIDTH				810
-#define GUI_HEIGHT			510
+#define GUI_WIDTH				   816
+#define GUI_HEIGHT			   510
+#define GUI_PLUGIN_RATE    0.05  // refresh rate for plugin GUIs
+#define GUI_FONT_SIZE_BASE 12
 
 #define COLOR_BD_0     fl_rgb_color(78,  78,  78)			// border off
 #define COLOR_BD_1     fl_rgb_color(188, 188, 188)    // border on
@@ -71,7 +76,6 @@
 #define MAX_BARS				   32
 #define MAX_PATCHNAME_LEN	 32
 #define DB_MIN_SCALE		   60.0f
-#define MAX_VST_EVENTS     32
 #define MIN_COLUMN_WIDTH   140
 
 
@@ -84,7 +88,8 @@
 #define SYS_API_ASIO		0x08  // 0000 1000
 #define SYS_API_CORE		0x10  // 0001 0000
 #define SYS_API_PULSE   0x20  // 0010 0000
-#define SYS_API_ANY     0x3F  // 0011 1111
+#define SYS_API_WASAPI  0x40  // 0100 0000
+#define SYS_API_ANY     0x7F  // 0111 1111
 
 #define KERNEL_OK					 0
 #define KERNEL_UNDERRUN	  -1
@@ -440,6 +445,11 @@ const int MIDI_CHANS[16] = {
 #define CONF_KEY_BEATS_Y                  "beats_y"
 #define CONF_KEY_ABOUT_X                  "about_x"
 #define CONF_KEY_ABOUT_Y                  "about_y"
+#define CONF_KEY_PLUGIN_CHOOSER_X         "plugin_chooser_x"
+#define CONF_KEY_PLUGIN_CHOOSER_Y         "plugin_chooser_y"
+#define CONF_KEY_PLUGIN_CHOOSER_W         "plugin_chooser_w"
+#define CONF_KEY_PLUGIN_CHOOSER_H         "plugin_chooser_h"
+#define CONF_KEY_PLUGIN_SORT_METHOD       "plugin_sort_method"
 
 /* JSON midimaps keys */
 
