@@ -1513,122 +1513,122 @@ const char *fxRemoveOn_xpm[] = {
 
 
 const char *beatsDivideOn_xpm[] = {
-"13 13 13 1",
-" 	c None",
-".	c #595B58",
-"+	c #5B5D5A",
-"@	c #5F615E",
-"#	c #686967",
-"$	c #737572",
-"%	c #787A77",
-"&	c #80827F",
-"*	c #8F918E",
-"=	c #959794",
-"-	c #9A9C99",
-";	c #C4C6C3",
-">	c #C7C9C6",
-".............",
-".............",
-".............",
-".............",
-".....#>#.....",
-"....+@%@+....",
-"...*>>>>>*...",
-"....+@%@+....",
-".....#>#.....",
-".............",
-".............",
-".............",
-"............."};
+"18 18 7 1",
+" 	c #5A5A5A",
+".	c #696969",
+"+	c #757575",
+"@	c #8B8B8B",
+"#	c #AAAAAA",
+"$	c #BBBBBB",
+"%	c #BDBDBD",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"        @@        ",
+"        %$        ",
+"        ++        ",
+"    .########.    ",
+"    .########.    ",
+"        ++        ",
+"        %$        ",
+"        @@        ",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"                  "};
 
 
 const char *beatsDivideOff_xpm[] = {
-"13 13 13 1",
-" 	c None",
-".	c #242523",
-"+	c #262825",
-"@	c #2D2E2C",
-"#	c #3A3B39",
-"$	c #494B48",
-"%	c #525451",
-"&	c #595B58",
-"*	c #5F615E",
-"=	c #787A77",
-"-	c #858784",
-";	c #C3C5C1",
-">	c #C7C9C6",
-".............",
-".............",
-".............",
-"......+......",
-".....#>#.....",
-"...++@%@++...",
-"...=>>>>>=...",
-"...++@%@++...",
-".....#>#.....",
-"......+......",
-".............",
-".............",
-"............."};
+"18 18 8 1",
+" 	c #252525",
+".	c #3B3B3B",
+"+	c #4D4D4D",
+"@	c #6D6D6D",
+"#	c #6E6E6E",
+"$	c #9C9C9C",
+"%	c #B5B5B5",
+"&	c #B7B7B7",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"        @#        ",
+"        &%        ",
+"        ++        ",
+"    .$$$$$$$$.    ",
+"    .$$$$$$$$.    ",
+"        ++        ",
+"        &%        ",
+"        @#        ",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"                  "};
 
 
 const char *beatsMultiplyOn_xpm[] = {
-"13 13 13 1",
-" 	c None",
-".	c #595B58",
-"+	c #5B5D5A",
-"@	c #5F615E",
-"#	c #686967",
-"$	c #737572",
-"%	c #787A77",
-"&	c #80827F",
-"*	c #8F918E",
-"=	c #959794",
-"-	c #9A9C99",
-";	c #C4C6C3",
-">	c #C7C9C6",
-".............",
-".............",
-".............",
-"....$...$....",
-"...$;&.&;$...",
-"....&;-;&....",
-".....->-.....",
-"....&;=;&....",
-"...$;&.&;$...",
-"...+$...$....",
-".............",
-".............",
-"............."};
+"18 18 8 1",
+" 	c #595B58",
+".	c #737572",
+"+	c #747673",
+"@	c #8B8D8A",
+"#	c #8D8F8C",
+"$	c #8E908D",
+"%	c #8F918E",
+"&	c #C7C9C6",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"      +    .      ",
+"     +&$  #&.     ",
+"      #&$#&#      ",
+"       @&&#       ",
+"       @&&%       ",
+"      @&#@&%      ",
+"     +&#  #&+     ",
+"      +    .      ",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"                  "};
 
 
 const char *beatsMultiplyOff_xpm[] = {
-"13 13 12 1",
+"18 18 8 1",
 " 	c #242523",
-".	c #262825",
-"+	c #2D2E2C",
-"@	c #3A3B39",
-"#	c #494B48",
-"$	c #525451",
-"%	c #595B58",
-"&	c #5F615E",
-"*	c #787A77",
-"=	c #858784",
-"-	c #C3C5C1",
-";	c #C7C9C6",
-"             ",
-"             ",
-"             ",
-"   .#   #.   ",
-"   #-& &-#   ",
-"    &-=-&    ",
-"     =;=     ",
-"    %-*-&    ",
-"   #-% %-#   ",
-"   .#   #.   ",
-"             ",
-"             ",
-"             "};
+".	c #4A4C49",
+"+	c #4D4E4C",
+"@	c #6D6F6C",
+"#	c #717370",
+"$	c #737572",
+"%	c #757774",
+"&	c #C7C9C6",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"      +    .      ",
+"     +&$  #&.     ",
+"      #&$#&#      ",
+"       @&&#       ",
+"       @&&%       ",
+"      @&$@&%      ",
+"     +&#  #&+     ",
+"      +    .      ",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"                  "};
 
 
 const char *channelStop_xpm[] = {
