@@ -57,7 +57,7 @@ extern MidiMapConf   G_MidiMap;
 extern gdMainWindow *mainWin;
 
 #ifdef WITH_VST
-extern PluginHost	   G_PluginHost;
+extern PluginHost G_PluginHost;
 #endif
 
 
@@ -71,6 +71,14 @@ void init_prepareParser()
 	G_Patch_DEPR_.setDefault();
 	G_Patch.init();
 
+#ifdef WITH_VST
+
+	G_PluginHost.init(G_Conf.buffersize, G_Conf.samplerate);
+	G_PluginHost.sortPlugins(G_Conf.pluginSortMethod);
+
+#endif
+
+
 	if (!gLog_init(G_Conf.logMode))
 		gLog("[init] log init failed! Using default stdout\n");
 
@@ -160,10 +168,6 @@ void init_startKernelAudio()
 {
 	if (G_audio_status)
 		kernelAudio::startStream();
-
-#ifdef WITH_VST
-	G_PluginHost.allocBuffers();
-#endif
 }
 
 
@@ -181,7 +185,7 @@ void init_shutdown()
 	G_Conf.mainWindowW = mainWin->w();
 	G_Conf.mainWindowH = mainWin->h();
 
-	/* close any open subwindow, especially before cleaning PluginHost to
+	/* close any open subwindow, especially before cleaning PluginHost_DEPR_ to
 	 * avoid mess */
 
 	gu_closeAllSubwindows();
@@ -207,8 +211,8 @@ void init_shutdown()
 	gLog("[init] Recorder cleaned up\n");
 
 #ifdef WITH_VST
-	G_PluginHost.freeAllStacks();
-	gLog("[init] Plugin Host cleaned up\n");
+	G_PluginHost.freeAllStacks(&G_Mixer.channels, &G_Mixer.mutex_plugins);
+	gLog("[init] PluginHost cleaned up\n");
 #endif
 
 	gLog("[init] Giada " G_VERSION_STR " closed\n\n");
