@@ -45,6 +45,7 @@
 
 
 extern Mixer 			 G_Mixer;
+extern MidiMapConf G_MidiMap;
 extern Patch_DEPR_ G_Patch_DEPR_;
 extern Conf				 G_Conf;
 #ifdef WITH_VST
@@ -156,9 +157,13 @@ Channel *Mixer::addChannel(int type)
 	int bufferSize = kernelAudio::realBufsize*2;
 
 	if (type == CHANNEL_SAMPLE)
-		ch = new SampleChannel(bufferSize);
+		ch = new SampleChannel(bufferSize, &G_MidiMap);
 	else
-		ch = new MidiChannel(bufferSize);
+		ch = new MidiChannel(bufferSize, &G_MidiMap);
+
+#ifdef WITH_VST
+	ch->setPluginHost(&G_PluginHost);
+#endif
 
 	while (true) {
 		int lockStatus = pthread_mutex_trylock(&mutex_chans);
@@ -443,7 +448,7 @@ int Mixer::__masterPlay(void *out_buf, void *in_buf, unsigned bufferFrames)
 			if (actualFrame == 0) {
 				pthread_mutex_lock(&mutex_chans);
 				for (unsigned k=0; k<channels.size(); k++)
-					channels.at(k)->onZero(j);
+					channels.at(k)->onZero(j, G_Conf.recsStopOnChanHalt);
 				pthread_mutex_unlock(&mutex_chans);
 			}
 
@@ -455,7 +460,7 @@ int Mixer::__masterPlay(void *out_buf, void *in_buf, unsigned bufferFrames)
 					for (unsigned z=0; z<recorder::global.at(y).size(); z++) {
 						int index   = recorder::global.at(y).at(z)->chan;
 						Channel *ch = getChannelByIndex(index);
-						ch->parseAction(recorder::global.at(y).at(z), j, actualFrame);
+						ch->parseAction(recorder::global.at(y).at(z), j, actualFrame, quantize, running);
 					}
 					break;
 				}
