@@ -75,11 +75,12 @@ static int __mh_readPatchPlugins__(vector<Patch::plugin_t> *list, int type)
 	int ret = 1;
 	for (unsigned i=0; i<list->size(); i++) {
 		Patch::plugin_t *ppl = &list->at(i);
-		Plugin *plugin = G_PluginHost.addPlugin(ppl->path.c_str(), type, NULL);
+		Plugin *plugin = G_PluginHost.addPlugin(ppl->path.c_str(), type,
+				&G_Mixer.mutex_plugins, NULL);
 		if (plugin != NULL) {
-			plugin->bypass = ppl->bypass;
+			plugin->setBypass(ppl->bypass);
 			for (unsigned j=0; j<ppl->params.size(); j++)
-				plugin->setParam(j, ppl->params.at(j));
+				plugin->setParameter(j, ppl->params.at(j));
 			ret &= 1;
 		}
 		else
@@ -98,7 +99,7 @@ void mh_stopSequencer()
 {
 	G_Mixer.running = false;
 	for (unsigned i=0; i<G_Mixer.channels.size(); i++)
-		G_Mixer.channels.at(i)->stopBySeq();
+		G_Mixer.channels.at(i)->stopBySeq(G_Conf.chansStopOnSeqHalt);
 }
 
 
@@ -131,7 +132,8 @@ void mh_loadPatch_DEPR_(bool isProject, const char *projPath)
 	for (int i=0; i<numChans; i++) {
 		Channel *ch = glue_addChannel(G_Patch_DEPR_.getColumn(i), G_Patch_DEPR_.getType(i));
 		string samplePath = isProject ? projPath + gGetSlash() + G_Patch_DEPR_.getSamplePath(i) : "";
-		ch->readPatch_DEPR_(samplePath.c_str(), i);
+		ch->readPatch_DEPR_(samplePath.c_str(), i, &G_Patch_DEPR_, G_Conf.samplerate,
+				G_Conf.rsmpQuality);
 	}
 
 	G_Mixer.outVol     = G_Patch_DEPR_.getOutVol();
@@ -230,7 +232,7 @@ SampleChannel *mh_startInputRec()
 		sprintf(name, "TAKE-%d", G_Patch_DEPR_.lastTakeId);
 	}
 
-	chan->allocEmpty(G_Mixer.totalFrames, G_Patch_DEPR_.lastTakeId);
+	chan->allocEmpty(G_Mixer.totalFrames, G_Conf.samplerate, G_Patch_DEPR_.lastTakeId);
 	G_Mixer.chanInput = chan;
 
 	/* start to write from the actualFrame, not the beginning */
