@@ -40,20 +40,11 @@
 #include "kernelMidi.h"
 
 
-extern Patch_DEPR_ G_Patch_DEPR_;
-extern Patch       G_Patch;
-extern Mixer       G_Mixer;
-extern Conf        G_Conf;
-#ifdef WITH_VST
-extern PluginHost  G_PluginHost;
-#endif
-
-
 using std::string;
 
 
-SampleChannel::SampleChannel(int bufferSize)
-	: Channel          (CHANNEL_SAMPLE, STATUS_EMPTY, bufferSize),
+SampleChannel::SampleChannel(int bufferSize, MidiMapConf *midiMapConf)
+	: Channel          (CHANNEL_SAMPLE, STATUS_EMPTY, bufferSize, midiMapConf),
 		frameRewind      (-1),
 		wave             (NULL),
 		tracker          (0),
@@ -93,9 +84,9 @@ SampleChannel::~SampleChannel()
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::copy(const Channel *_src)
+void SampleChannel::copy(const Channel *_src, pthread_mutex_t *pluginMutex)
 {
-	Channel::copy(_src);
+	Channel::copy(_src, pluginMutex);
 	SampleChannel *src = (SampleChannel *) _src;
 	tracker         = src->tracker;
 	begin           = src->begin;
@@ -287,7 +278,8 @@ void SampleChannel::rewind()
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::parseAction(recorder::action *a, int localFrame, int globalFrame)
+void SampleChannel::parseAction(recorder::action *a, int localFrame,
+		int globalFrame, int quantize, bool mixerIsRunning)
 {
 	if (readActions == false)
 		return;
@@ -295,7 +287,7 @@ void SampleChannel::parseAction(recorder::action *a, int localFrame, int globalF
 	switch (a->type) {
 		case ACTION_KEYPRESS:
 			if (mode & SINGLE_ANY)
-				start(localFrame, false);
+				start(localFrame, false, quantize, mixerIsRunning);
 			break;
 		case ACTION_KEYREL:
 			if (mode & SINGLE_ANY)
@@ -434,7 +426,7 @@ void SampleChannel::sum(int frame, bool running)
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::onZero(int frame)
+void SampleChannel::onZero(int frame, bool recsStopOnChanHalt)
 {
 	if (wave == NULL)
 		return;
@@ -466,12 +458,12 @@ void SampleChannel::onZero(int frame)
 
 	if (recStatus == REC_ENDING) {
 		recStatus = REC_STOPPED;
-		setReadActions(false);  // rec stop
+		setReadActions(false, recsStopOnChanHalt);  // rec stop
 	}
 	else
 	if (recStatus == REC_WAITING) {
 		recStatus = REC_READING;
-		setReadActions(true);   // rec start
+		setReadActions(true, recsStopOnChanHalt);   // rec start
 	}
 }
 
@@ -609,13 +601,13 @@ void SampleChannel::calcFadeoutStep()
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::setReadActions(bool v)
+void SampleChannel::setReadActions(bool v, bool recsStopOnChanHalt)
 {
 	if (v)
 		readActions = true;
 	else {
 		readActions = false;
-		if (G_Conf.recsStopOnChanHalt)
+		if (recsStopOnChanHalt)
 			kill(0);  /// FIXME - wrong frame value
 	}
 }
@@ -714,17 +706,14 @@ void SampleChannel::pushWave(Wave *w)
 /* -------------------------------------------------------------------------- */
 
 
-bool SampleChannel::allocEmpty(int frames, int takeId)
+bool SampleChannel::allocEmpty(int frames, int samplerate, int takeId)
 {
 	Wave *w = new Wave();
-	if (!w->allocEmpty(frames, G_Conf.samplerate))
+	if (!w->allocEmpty(frames, samplerate))
 		return false;
 
-	char wname[32];
-	sprintf(wname, "TAKE-%d", takeId);
-
-	w->pathfile = gGetCurrentPath()+"/"+wname; // FIXME - use gGetSlash() in utils.h
-	w->name     = wname;
+	w->name     = "TAKE-" + gItoa(takeId);
+	w->pathfile = gGetCurrentPath() + gGetSlash() + w->name;
 	wave        = w;
 	status      = STATUS_OFF;
 	begin       = 0;
@@ -742,7 +731,7 @@ bool SampleChannel::allocEmpty(int frames, int takeId)
 void SampleChannel::process(float *buffer)
 {
 #ifdef WITH_VST
-	G_PluginHost.processStack(vChan, PluginHost::CHANNEL, this);
+	pluginHost->processStack(vChan, PluginHost::CHANNEL, this);
 #endif
 
 	for (int j=0; j<bufferSize; j+=2) {
@@ -769,7 +758,7 @@ void SampleChannel::kill(int frame)
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::stopBySeq()
+void SampleChannel::stopBySeq(bool chansStopOnSeqHalt)
 {
   /* Loop-mode samples in wait status get stopped right away. */
 
@@ -790,7 +779,7 @@ void SampleChannel::stopBySeq()
    *  - Recorder's channel is active (altrimenti può capitare che si stoppino i
    *    sample suonati manualmente in un canale con rec disattivate) */
 
-	if (G_Conf.chansStopOnSeqHalt) {
+	if (chansStopOnSeqHalt) {
     if ((mode & LOOP_ANY) || (hasActions && readActions && status == STATUS_PLAY))
       kill(0);
   }
@@ -817,7 +806,7 @@ void SampleChannel::stop()
 /* -------------------------------------------------------------------------- */
 
 
-int SampleChannel::load(const char *file)
+int SampleChannel::load(const char *file, int samplerate, int rsmpQuality)
 {
 	if (strcmp(file, "") == 0 || gIsDir(file)) {
 		gLog("[SampleChannel] file not specified\n");
@@ -849,10 +838,10 @@ int SampleChannel::load(const char *file)
 	if (w->channels() == 1) /** FIXME: error checking  */
 		wfx_monoToStereo(w);
 
-	if (w->rate() != G_Conf.samplerate) {
+	if (w->rate() != samplerate) {
 		gLog("[SampleChannel] input rate (%d) != system rate (%d), conversion needed\n",
-				w->rate(), G_Conf.samplerate);
-		w->resample(G_Conf.rsmpQuality, G_Conf.samplerate);
+				w->rate(), samplerate);
+		w->resample(rsmpQuality, samplerate);
 	}
 
 	pushWave(w);
@@ -866,32 +855,33 @@ int SampleChannel::load(const char *file)
 /* -------------------------------------------------------------------------- */
 
 
-int SampleChannel::readPatch_DEPR_(const char *f, int i)
+int SampleChannel::readPatch_DEPR_(const char *f, int i, Patch_DEPR_ *patch,
+		int samplerate, int rsmpQuality)
 {
-	int res = load(f);
+	int res = load(f, samplerate, rsmpQuality);
 
-		volume      = G_Patch_DEPR_.getVol(i);
-		key         = G_Patch_DEPR_.getKey(i);
-		index       = G_Patch_DEPR_.getIndex(i);
-		mode        = G_Patch_DEPR_.getMode(i);
-		mute        = G_Patch_DEPR_.getMute(i);
-		mute_s      = G_Patch_DEPR_.getMute_s(i);
-		solo        = G_Patch_DEPR_.getSolo(i);
-		boost       = G_Patch_DEPR_.getBoost(i);
-		panLeft     = G_Patch_DEPR_.getPanLeft(i);
-		panRight    = G_Patch_DEPR_.getPanRight(i);
-		readActions = G_Patch_DEPR_.getRecActive(i);
+		volume      = patch->getVol(i);
+		key         = patch->getKey(i);
+		index       = patch->getIndex(i);
+		mode        = patch->getMode(i);
+		mute        = patch->getMute(i);
+		mute_s      = patch->getMute_s(i);
+		solo        = patch->getSolo(i);
+		boost       = patch->getBoost(i);
+		panLeft     = patch->getPanLeft(i);
+		panRight    = patch->getPanRight(i);
+		readActions = patch->getRecActive(i);
 		recStatus   = readActions ? REC_READING : REC_STOPPED;
 
-		readPatchMidiIn_DEPR_(i);
-		midiInReadActions = G_Patch_DEPR_.getMidiValue(i, "InReadActions");
-		midiInPitch       = G_Patch_DEPR_.getMidiValue(i, "InPitch");
-		readPatchMidiOut_DEPR_(i);
+		readPatchMidiIn_DEPR_(i, *patch);
+		midiInReadActions = patch->getMidiValue(i, "InReadActions");
+		midiInPitch       = patch->getMidiValue(i, "InPitch");
+		readPatchMidiOut_DEPR_(i, *patch);
 
 	if (res == SAMPLE_LOADED_OK) {
-		setBegin(G_Patch_DEPR_.getBegin(i));
-		setEnd  (G_Patch_DEPR_.getEnd(i, wave->size));
-		setPitch(G_Patch_DEPR_.getPitch(i));
+		setBegin(patch->getBegin(i));
+		setEnd  (patch->getEnd(i, wave->size));
+		setPitch(patch->getPitch(i));
 	}
 	else {
 		// volume = DEFAULT_VOL;
@@ -914,14 +904,15 @@ int SampleChannel::readPatch_DEPR_(const char *f, int i)
 /* -------------------------------------------------------------------------- */
 
 
-int SampleChannel::readPatch(const string &basePath, int i)
+int SampleChannel::readPatch(const string &basePath, int i, Patch *patch,
+		pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality)
 {
 	/* load channel's data first: if the sample is missing or wrong, the channel
 	 * is not completely blank. */
 
-	Channel::readPatch("", i);
+	Channel::readPatch("", i, patch, pluginMutex, samplerate, rsmpQuality);
 
-	Patch::channel_t *pch = &G_Patch.channels.at(i);
+	Patch::channel_t *pch = &patch->channels.at(i);
 
 	mode              = pch->mode;
 	boost             = pch->boost;
@@ -930,7 +921,7 @@ int SampleChannel::readPatch(const string &basePath, int i)
 	midiInReadActions = pch->midiInReadActions;
 	midiInPitch       = pch->midiInPitch;
 
-	int res = load((basePath + pch->samplePath).c_str());
+	int res = load((basePath + pch->samplePath).c_str(), samplerate, rsmpQuality);
 	if (res == SAMPLE_LOADED_OK) {
 		setBegin(pch->begin);
 		setEnd  (pch->end);
@@ -961,7 +952,8 @@ bool SampleChannel::canInputRec()
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::start(int frame, bool doQuantize)
+void SampleChannel::start(int frame, bool doQuantize, int quantize,
+		bool mixerIsRunning)
 {
 	switch (status)	{
 		case STATUS_EMPTY:
@@ -978,7 +970,7 @@ void SampleChannel::start(int frame, bool doQuantize)
 				sendMidiLplay();
 			}
 			else {
-				if (G_Mixer.quantize > 0 && G_Mixer.running && doQuantize)
+				if (quantize > 0 && mixerIsRunning && doQuantize)
 					qWait = true;
 				else {
 
@@ -1000,7 +992,7 @@ void SampleChannel::start(int frame, bool doQuantize)
 				setFadeOut(DO_STOP);
 			else
 			if (mode == SINGLE_RETRIG) {
-				if (G_Mixer.quantize > 0 && G_Mixer.running && doQuantize)
+				if (quantize > 0 && mixerIsRunning && doQuantize)
 					qWait = true;
 				else
 					reset(frame);
@@ -1033,10 +1025,10 @@ void SampleChannel::start(int frame, bool doQuantize)
 /* -------------------------------------------------------------------------- */
 
 
-int SampleChannel::writePatch(int i, bool isProject)
+int SampleChannel::writePatch(int i, bool isProject, Patch *patch)
 {
-	int pchIndex = Channel::writePatch(i, isProject);
-	Patch::channel_t *pch = &G_Patch.channels.at(pchIndex);
+	int pchIndex = Channel::writePatch(i, isProject, patch);
+	Patch::channel_t *pch = &patch->channels.at(pchIndex);
 
 	if (wave != NULL) {
 		pch->samplePath = wave->pathfile;
