@@ -64,7 +64,7 @@ extern Patch_DEPR_   G_Patch_DEPR_;
 extern Conf	 	   		 G_Conf;
 extern bool 		 		 G_audio_status;
 #ifdef WITH_VST
-extern PluginHost		 G_PluginHost;
+extern PluginHost    G_PluginHost;
 #endif
 
 
@@ -305,7 +305,7 @@ void glue_startReadingRecs(SampleChannel *ch, bool gui) {
 	if (G_Conf.treatRecsAsLoops)
 		ch->recStatus = REC_WAITING;
 	else
-		ch->setReadActions(true);
+		ch->setReadActions(true, G_Conf.recsStopOnChanHalt);
 	if (!gui) {
 		gSampleChannel *gch = (gSampleChannel*)ch->guiChannel;
 		if (gch->readActions) { // if button exists
@@ -328,7 +328,7 @@ void glue_stopReadingRecs(SampleChannel *ch, bool gui) {
 	if (G_Conf.treatRecsAsLoops)
 		ch->recStatus = REC_ENDING;
 	else
-		ch->setReadActions(false);
+		ch->setReadActions(false, G_Conf.recsStopOnChanHalt);
 	if (!gui) {
 		gSampleChannel *gch = (gSampleChannel*)ch->guiChannel;
 		if (gch->readActions) {  // if button exists
@@ -436,7 +436,7 @@ void glue_resetToInitState(bool resetGui, bool createColumns)
 	G_Mixer.init();
 	recorder::init();
 #ifdef WITH_VST
-	G_PluginHost.freeAllStacks();
+	G_PluginHost.freeAllStacks(&G_Mixer.channels, &G_Mixer.mutex_plugins);
 #endif
 
 	mainWin->keyboard->clear();
@@ -793,7 +793,7 @@ int glue_stopInputRec(bool gui)
 	SampleChannel *ch = mh_stopInputRec();
 
 	if (ch->mode & (LOOP_BASIC | LOOP_ONCE | LOOP_REPEAT))
-		ch->start(0, true);  // on frame 0: user-generated event
+		ch->start(0, true, G_Mixer.quantize, G_Mixer.running);  // on frame 0: user-generated event
 
 	if (!gui) {
 		Fl::lock();
@@ -838,7 +838,7 @@ void glue_keyPress(MidiChannel *ch, bool ctrl, bool shift)
 	if (shift)
 		ch->kill(0);        // on frame 0: user-generated event
 	else
-		ch->start(0, true); // on frame 0: user-generated event
+		ch->start(0, true, G_Mixer.quantize, G_Mixer.running); // on frame 0: user-generated event
 }
 
 
@@ -901,7 +901,7 @@ void glue_keyPress(SampleChannel *ch, bool ctrl, bool shift)
 				recorder::rec(ch->index, ACTION_KEYPRESS, G_Mixer.actualFrame);
 		}
 
-		ch->start(0, true); // on frame 0: user-generated event
+		ch->start(0, true, G_Mixer.quantize, G_Mixer.running); // on frame 0: user-generated event
 	}
 
 	/* the GUI update is done by gui_refresh() */
