@@ -32,6 +32,7 @@
 #include "../../core/patch_DEPR_.h"
 #include "../../core/kernelAudio.h"
 #include "../../core/kernelMidi.h"
+#include "../../core/pluginHost.h"
 #include "../../utils/gui_utils.h"
 #include "../../utils/log.h"
 #include "../elems/ge_mixed.h"
@@ -46,6 +47,10 @@ extern Conf	       G_Conf;
 extern bool        G_audio_status;
 extern MidiMapConf G_MidiMap;
 
+#ifdef WITH_VST
+extern PluginHost G_PluginHost;
+#endif
+
 
 using std::string;
 
@@ -61,7 +66,7 @@ gTabMisc::gTabMisc(int X, int Y, int W, int H)
 	debugMsg->add("To standard output");
 	debugMsg->add("To file");
 
-	labelsize(11);
+	labelsize(GUI_FONT_SIZE_BASE);
 
 	switch (G_Conf.logMode) {
 		case LOG_MODE_MUTE:
@@ -120,7 +125,7 @@ gTabAudio::gTabAudio(int X, int Y, int W, int H)
                 new gBox(x(), rsmpQuality->y()+rsmpQuality->h()+8, w(), 92,
 										"Restart Giada for the changes to take effect.");
 	end();
-	labelsize(11);
+	labelsize(GUI_FONT_SIZE_BASE);
 
 	soundsys->add("(none)");
 
@@ -156,6 +161,8 @@ gTabAudio::gTabAudio(int X, int Y, int W, int H)
 		soundsys->add("DirectSound");
 	if (kernelAudio::hasAPI(RtAudio::WINDOWS_ASIO))
 		soundsys->add("ASIO");
+	if (kernelAudio::hasAPI(RtAudio::WINDOWS_WASAPI))
+		soundsys->add("WASAPI");
 
 	switch (G_Conf.soundSystem) {
 		case SYS_API_NONE:
@@ -167,6 +174,9 @@ gTabAudio::gTabAudio(int X, int Y, int W, int H)
 		case SYS_API_ASIO:
 			soundsys->showItem("ASIO");
 			break;
+		case SYS_API_WASAPI:
+			soundsys->showItem("WASAPI");
+			break;
 	}
 
 #elif defined (__APPLE__)
@@ -580,7 +590,7 @@ gTabMidi::gTabMidi(int X, int Y, int W, int H)
 	new gBox(x(), sync->y()+sync->h()+8, w(), h()-125, "Restart Giada for the changes to take effect.");
 	end();
 
-	labelsize(11);
+	labelsize(GUI_FONT_SIZE_BASE);
 
 	system->callback(cb_changeSystem, (void*)this);
 
@@ -797,7 +807,7 @@ gTabBehaviors::gTabBehaviors(int X, int Y, int W, int H)
 	treatRecsAsLoops  = new gCheck(x(), y()+155, 280, 20, "Treat one shot channels with actions as loops");
 
 	end();
-	labelsize(11);
+	labelsize(GUI_FONT_SIZE_BASE);
 
 	G_Conf.recsStopOnChanHalt == 1 ? recsStopOnChanHalt_1->value(1) : recsStopOnChanHalt_0->value(1);
 	G_Conf.chansStopOnSeqHalt == 1 ? chansStopOnSeqHalt_1->value(1) : chansStopOnSeqHalt_0->value(1);
@@ -841,6 +851,88 @@ void gTabBehaviors::save()
 /* -------------------------------------------------------------------------- */
 
 
+#ifdef WITH_VST
+
+gTabPlugins::gTabPlugins(int X, int Y, int W, int H)
+	: Fl_Group(X, Y, W, H, "Plugins")
+{
+	folderPath = new gInput(x()+w()-250, y()+8, 250, 20);
+	scanButton = new gClick(x()+w()-120, folderPath->y()+folderPath->h()+8, 120, 20);
+	info       = new gBox(x(), scanButton->y()+scanButton->h()+8, w(), 242);
+
+	end();
+
+	labelsize(GUI_FONT_SIZE_BASE);
+
+	info->label("Scan in progress. Please wait...");
+	info->hide();
+
+	folderPath->value(G_Conf.pluginPath.c_str());
+	folderPath->label("Plugins folder");
+
+	scanButton->callback(cb_scan, (void*) this);
+
+	updateCount();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void gTabPlugins::updateCount()
+{
+	string scanLabel = "Scan (" + gItoa(G_PluginHost.countAvailablePlugins()) + " found)";
+	scanButton->label(scanLabel.c_str());
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void gTabPlugins::cb_scan(Fl_Widget *w, void *p) { ((gTabPlugins*)p)->__cb_scan(w); }
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void gTabPlugins::cb_onScan(float progress, void *p)
+{
+	string l = "Scan in progress (" + gItoa((int)(progress*100)) + "%). Please wait...";
+	((gTabPlugins *)p)->info->label(l.c_str());
+	Fl::wait();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void gTabPlugins::__cb_scan(Fl_Widget *w)
+{
+	info->show();
+	G_PluginHost.scanDir(folderPath->value(), cb_onScan, (void*) this);
+	G_PluginHost.saveList(gGetHomePath() + gGetSlash() + "plugins.xml");
+	info->hide();
+	updateCount();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void gTabPlugins::save()
+{
+	G_Conf.pluginPath = folderPath->value();
+}
+
+
+#endif // if WITH_VST
+
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+
 gdConfig::gdConfig(int w, int h) : gWindow(w, h, "Configuration")
 {
 	set_modal();
@@ -853,6 +945,10 @@ gdConfig::gdConfig(int w, int h) : gWindow(w, h, "Configuration")
 		tabMidi      = new gTabMidi(tabs->x()+10, tabs->y()+20, tabs->w()-20, tabs->h()-40);
 		tabBehaviors = new gTabBehaviors(tabs->x()+10, tabs->y()+20, tabs->w()-20, tabs->h()-40);
 		tabMisc      = new gTabMisc(tabs->x()+10, tabs->y()+20, tabs->w()-20, tabs->h()-40);
+#ifdef WITH_VST
+		tabPlugins   = new gTabPlugins(tabs->x()+10, tabs->y()+20, tabs->w()-20, tabs->h()-40);
+#endif
+
 	tabs->end();
 
 	save 	 = new gClick (w-88, h-28, 80, 20, "Save");
@@ -899,6 +995,9 @@ void gdConfig::__cb_save_config()
 	tabBehaviors->save();
 	tabMidi->save();
 	tabMisc->save();
+#ifdef WITH_VST
+	tabPlugins->save();
+#endif
 	do_callback();
 }
 
