@@ -36,12 +36,12 @@
 #include "../../core/mixer.h"
 #include "../../core/recorder.h"
 #include "../../core/mixerHandler.h"
-#include "../../core/pluginHost.h"
 #include "../../core/channel.h"
 #include "../../core/sampleChannel.h"
 #include "../../core/init.h"
 #include "../../core/patch_DEPR_.h"
 #include "../../core/conf.h"
+#include "../../core/pluginHost.h"
 #include "../../glue/glue.h"
 #include "../elems/ge_keyboard.h"
 #include "gd_warnings.h"
@@ -52,11 +52,7 @@
 #include "gd_config.h"
 #include "gd_browser.h"
 #include "gd_mainWindow.h"
-
-
-#ifdef WITH_VST
 #include "gd_pluginList.h"
-#endif
 
 
 extern Mixer	   		 G_Mixer;
@@ -66,10 +62,6 @@ extern gdMainWindow *mainWin;
 extern bool	 		 		 G_quit;
 extern bool 		 		 G_audio_status;
 
-#if defined(WITH_VST)
-extern PluginHost  	 G_PluginHost;
-#endif
-
 
 gdMainWindow::gdMainWindow(int W, int H, const char *title, int argc, char **argv)
 	: gWindow(W, H, title)
@@ -81,9 +73,9 @@ gdMainWindow::gdMainWindow(int W, int H, const char *title, int argc, char **arg
 	size_range(GUI_WIDTH, GUI_HEIGHT);
 
 	menu       = new gMenu(8, -1);
-	inOut      = new gInOut(408, 8);
+	inOut      = new gInOut(414, 8);
 	controller = new gController(8, 39);
-	timing     = new gTiming(632, 39);
+	timing     = new gTiming(628, 44);
 	beatMeter  = new gBeatMeter(100, 83, 609, 20);
 	keyboard   = new gKeyboard(8, 122, w()-16, 380);
 
@@ -316,7 +308,7 @@ void gMenu::__cb_file()
 
 	Fl_Menu_Button *b = new Fl_Menu_Button(0, 0, 100, 50);
 	b->box(G_BOX);
-	b->textsize(11);
+	b->textsize(GUI_FONT_SIZE_BASE);
 	b->textcolor(COLOR_TEXT_0);
 	b->color(COLOR_BG_0);
 
@@ -382,7 +374,7 @@ void gMenu::__cb_edit()
 
 	Fl_Menu_Button *b = new Fl_Menu_Button(0, 0, 100, 50);
 	b->box(G_BOX);
-	b->textsize(11);
+	b->textsize(GUI_FONT_SIZE_BASE);
 	b->textcolor(COLOR_TEXT_0);
 	b->color(COLOR_BG_0);
 
@@ -427,15 +419,15 @@ void gMenu::__cb_edit()
 
 
 gTiming::gTiming(int x, int y)
-	: Fl_Group(x, y, 170, 15)
+	: Fl_Group(x, y, 180, 20)
 {
 	begin();
 
-	quantizer  = new gChoice(x, y, 40, 15, "", false);
-	bpm        = new gClick (quantizer->x()+quantizer->w()+4,  y, 40, 15);
-	meter      = new gClick (bpm->x()+bpm->w()+8,  y, 40, 15, "4/1");
-	multiplier = new gClick (meter->x()+meter->w()+4, y, 15, 15, "", beatsMultiplyOff_xpm, beatsMultiplyOn_xpm);
-	divider    = new gClick (multiplier->x()+multiplier->w()+4, y, 15, 15, "÷", beatsDivideOff_xpm, beatsDivideOn_xpm);
+	quantizer  = new gChoice(x, y, 40, 20, "", false);
+	bpm        = new gClick (quantizer->x()+quantizer->w()+4,  y, 40, 20);
+	meter      = new gClick (bpm->x()+bpm->w()+8,  y, 40, 20, "4/1");
+	multiplier = new gClick (meter->x()+meter->w()+4, y, 20, 20, "", beatsMultiplyOff_xpm, beatsMultiplyOn_xpm);
+	divider    = new gClick (multiplier->x()+multiplier->w()+4, y, 20, 20, "", beatsDivideOff_xpm, beatsDivideOn_xpm);
 
 	end();
 
