@@ -35,11 +35,13 @@
 #include "../../core/conf.h"
 #include "../../core/graphics.h"
 #include "../../core/pluginHost.h"
+#include "../../core/plugin.h"
 #include "../../core/mixer.h"
 #include "../../core/channel.h"
 #include "../elems/ge_mixed.h"
 #include "../elems/ge_channel.h"
 #include "gd_pluginList.h"
+#include "gd_pluginChooser.h"
 #include "gd_pluginWindow.h"
 #include "gd_pluginWindowGUI.h"
 #include "gd_browser.h"
@@ -47,14 +49,17 @@
 
 
 extern Conf          G_Conf;
+extern Mixer         G_Mixer;
 extern PluginHost    G_PluginHost;
 extern gdMainWindow *mainWin;
 
 
-gdPluginList::gdPluginList(int stackType, Channel *ch)
- : gWindow(468, 204), ch(ch), stackType(stackType)
-{
+using std::string;
 
+
+gdPluginList::gdPluginList(int stackType, Channel *ch)
+  : gWindow(468, 204), ch(ch), stackType(stackType)
+{
 	if (G_Conf.pluginListX)
 		resize(G_Conf.pluginListX, G_Conf.pluginListY, w(), h());
 
@@ -81,9 +86,8 @@ gdPluginList::gdPluginList(int stackType, Channel *ch)
 	if (stackType == PluginHost::MASTER_IN)
 		label("Master In Plugins");
 	else {
-		char tmp[32];
-		sprintf(tmp, "Channel %d Plugins", ch->index+1);
-		copy_label(tmp);
+    string l = "Channel " + gItoa(ch->index+1) + " Plugins";
+    copy_label(l.c_str());
 	}
 
 	gu_setFavicon(this);
@@ -136,12 +140,19 @@ void gdPluginList::__cb_addPlugin() {
 	/* the usual callback that gWindow adds to each subwindow in this case
 	 * is not enough, because when we close the browser the plugin list
 	 * must be redrawn. We have a special callback, cb_refreshList, which
-	 * we add to gdBrowser. It does exactly what we need. */
+	 * we add to gdPluginChooser. It does exactly what we need. */
 
-	gdBrowser *b = new gdBrowser("Browse Plugin", G_Conf.pluginPath.c_str(), ch, BROWSER_LOAD_PLUGIN, stackType);
+  gdPluginChooser *pc = new gdPluginChooser(G_Conf.pluginChooserX,
+      G_Conf.pluginChooserY, G_Conf.pluginChooserW, G_Conf.pluginChooserH,
+      stackType, ch);
+  addSubWindow(pc);
+  pc->callback(cb_refreshList, (void*)this);	// 'this' refers to gdPluginList
+
+#if 0
+	gdBrowser *b = new gdBrowser("Browse Plugin_DEPR_", G_Conf.pluginPath.c_str(), ch, BROWSER_LOAD_PLUGIN, stackType);
 	addSubWindow(b);
 	b->callback(cb_refreshList, (void*)this);	// 'this' refers to gdPluginList
-
+#endif
 }
 
 
@@ -163,8 +174,8 @@ void gdPluginList::refreshList() {
 	int i = 0;
 
 	while (i<numPlugins) {
-		Plugin   *pPlugin  = G_PluginHost.getPluginByIndex(i, stackType, ch);
-		gdPlugin *gdp      = new gdPlugin(this, pPlugin, list->x(), list->y()-list->yposition()+(i*24), 800);
+		Plugin   *pPlugin = G_PluginHost.getPluginByIndex(i, stackType, ch);
+		gdPlugin *gdp     = new gdPlugin(this, pPlugin, list->x(), list->y()-list->yposition()+(i*24), 800);
 		list->add(gdp);
 		i++;
 	}
@@ -190,11 +201,13 @@ void gdPluginList::refreshList() {
   gdPluginListMaster */
 
 	if (stackType == PluginHost::MASTER_OUT) {
-    mainWin->inOut->setMasterFxOutFull(G_PluginHost.countPlugins(stackType, ch) > 0);
+    mainWin->inOut->setMasterFxOutFull(
+			G_PluginHost.countPlugins(stackType, ch) > 0);
   }
 	else
 	if (stackType == PluginHost::MASTER_IN) {
-    mainWin->inOut->setMasterFxInFull(G_PluginHost.countPlugins(stackType, ch) > 0);
+    mainWin->inOut->setMasterFxInFull(
+			G_PluginHost.countPlugins(stackType, ch) > 0);
   }
 	else {
     ch->guiChannel->fx->full = G_PluginHost.countPlugins(stackType, ch) > 0;
@@ -220,46 +233,31 @@ gdPlugin::gdPlugin(gdPluginList *gdp, Plugin *p, int X, int Y, int W)
 	remove    = new gButton(shiftDown->x()+shiftDown->w()+4, y(), 20, 20, "", fxRemoveOff_xpm, fxRemoveOn_xpm);
 	end();
 
-	if (pPlugin->status != 1) {  // bad state
-		char name[256];
-		sprintf(name, "* %s *", gBasename(pPlugin->pathfile).c_str());
-		button->copy_label(name);
+	if (pPlugin->getStatus() != 1) {  // bad state
+    string l = "* " + pPlugin->getName().toStdString() + " *";
+		button->copy_label(l.c_str());
 	}
 	else {
-		char name[256];
-		pPlugin->getProduct(name);
-		if (strcmp(name, " ")==0)
-			pPlugin->getName(name);
-
-		button->copy_label(name);
+		button->copy_label(pPlugin->getName().toStdString().c_str());
 		button->callback(cb_openPluginWindow, (void*)this);
 
 		program->callback(cb_setProgram, (void*)this);
 
-		/* loading vst programs */
-		/* FIXME - max programs = 128 (unknown source) */
+    for (int i=0; i<pPlugin->getNumPrograms(); i++) {
+      string name = gu_removeFltkChars(pPlugin->getProgramName(i).toStdString());
+      program->add(name.c_str());
+    }
 
-		for (int i=0; i<64; i++) {
-			char out[kVstMaxProgNameLen];
-			pPlugin->getProgramName(i, out);
-			for (int j=0; j<kVstMaxProgNameLen; j++)  // escape FLTK special chars
-				if (out[j] == '/' || out[j] == '\\' || out[j] == '&' || out[j] == '_')
-					out[j] = '-';
-			if (strlen(out) > 0)
-				program->add(out);
-		}
 		if (program->size() == 0) {
 			program->add("-- no programs --\0");
 			program->deactivate();
 		}
-		if (pPlugin->getProgram() == -1)
-			program->value(0);
-		else
-			program->value(pPlugin->getProgram());
+    else
+      program->value(pPlugin->getCurrentProgram());
 
 		bypass->callback(cb_setBypass, (void*)this);
 		bypass->type(FL_TOGGLE_BUTTON);
-		bypass->value(pPlugin->bypass ? 0 : 1);
+		bypass->value(pPlugin->isBypassed() ? 0 : 1);
 	}
 
 	shiftUp->callback(cb_shiftUp, (void*)this);
@@ -294,7 +292,8 @@ void gdPlugin::__cb_shiftUp() {
 	if (pluginIndex == 0)  // first of the stack, do nothing
 		return;
 
-	G_PluginHost.swapPlugin(pluginIndex, pluginIndex-1, pParent->stackType, pParent->ch);
+	G_PluginHost.swapPlugin(pluginIndex, pluginIndex - 1, pParent->stackType,
+    &G_Mixer.mutex_plugins, pParent->ch);
 	pParent->refreshList();
 }
 
@@ -315,7 +314,8 @@ void gdPlugin::__cb_shiftDown() {
 	if (pluginIndex == stackSize-1)  // last one in the stack, do nothing
 		return;
 
-	G_PluginHost.swapPlugin(pluginIndex, pluginIndex+1, pParent->stackType, pParent->ch);
+	G_PluginHost.swapPlugin(pluginIndex, pluginIndex + 1, pParent->stackType,
+    &G_Mixer.mutex_plugins, pParent->ch);
 	pParent->refreshList();
 }
 
@@ -325,29 +325,45 @@ void gdPlugin::__cb_shiftDown() {
 
 void gdPlugin::__cb_removePlugin() {
 
-	/* os x hack: show window before deleting it */
-
-#ifdef __APPLE__
-	gdPluginWindowGUImac* w = (gdPluginWindowGUImac*) pParent->getChild(pPlugin->getId()+1);
-	if (w)
-		w->show();
-#endif
-
 	/* any subwindow linked to the plugin must be destroyed */
 
-	pParent->delSubWindow(pPlugin->getId()+1);
-	G_PluginHost.freePlugin(pPlugin->getId(), pParent->stackType, pParent->ch);
-	pParent->refreshList();
+	pParent->delSubWindow(pPlugin->getId());
+	G_PluginHost.freePlugin(pPlugin->getId(), pParent->stackType,
+    &G_Mixer.mutex_plugins, pParent->ch);
+
+  pParent->refreshList();
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void gdPlugin::__cb_openPluginWindow() {
+void gdPlugin::__cb_openPluginWindow()
+{
+  /* the new pluginWindow has id = id_plugin + 1, because id=0 is reserved
+  * for the parent window 'add plugin'. */
 
-	/* the new pluginWindow has id = id_plugin + 1, because id=0 is reserved
-	 * for the window 'add plugin'. */
+  gWindow *w;
+  if (pPlugin->hasEditor()) {
+    if (pPlugin->isEditorOpen()) {
+      gLog("[gdPlugin::__cb_openPluginWindow] plugin has editor but it's already visible\n");
+      return;
+    }
+
+    int pwid = pPlugin->getId()+1;
+
+    gLog("[gdPlugin::__cb_openPluginWindow] plugin has editor, open window id=%d\n", pwid);
+
+    if (pParent->hasWindow(pwid))
+      pParent->delSubWindow(pwid);
+    w = new gdPluginWindowGUI(pPlugin);
+    w->setId(pwid);
+		pParent->addSubWindow(w);
+  }
+  else {
+    w = new gdPluginWindow(pPlugin);
+  }
+#if 0
 
 	/* TODO - at the moment you can open a window for each plugin in the stack.
 	 * This is not consistent with the rest of the gui. You can avoid this by
@@ -361,7 +377,7 @@ void gdPlugin::__cb_openPluginWindow() {
 
 	if (!pParent->hasWindow(pPlugin->getId()+1)) {
 		gWindow *w;
-		if (pPlugin->hasGui())
+		if (pPlugin->hasEditor())
 #ifdef __APPLE__
 			w = new gdPluginWindowGUImac(pPlugin);
 #else
@@ -372,6 +388,7 @@ void gdPlugin::__cb_openPluginWindow() {
 		w->setId(pPlugin->getId()+1);
 		pParent->addSubWindow(w);
 	}
+#endif
 }
 
 
@@ -379,7 +396,7 @@ void gdPlugin::__cb_openPluginWindow() {
 
 
 void gdPlugin::__cb_setBypass() {
-	pPlugin->bypass = !pPlugin->bypass;
+	pPlugin->toggleBypass();
 }
 
 
@@ -387,7 +404,7 @@ void gdPlugin::__cb_setBypass() {
 
 
 void gdPlugin::__cb_setProgram() {
-	pPlugin->setProgram(program->value());
+	pPlugin->setCurrentProgram(program->value());
 }
 
 
